@@ -8,26 +8,7 @@ use base qw(Moose::Error::Default);
 use strict;
 use warnings;
 
-sub new {
-    my ( $self, %params ) = @_;
-    
-    my $exception = Business::UPS::Tracking::X::CLASS->new( 
-        error       => $params{message},
-        method      => $params{method},
-        depth       => $params{depth},
-        evaltext    => $params{evaltext},
-        sub_name    => $params{sub_name},
-        last_error  => $params{last_error},
-        sub         => $params{sub},
-        is_require  => $params{is_require},
-        has_args    => $params{has_args},
-    );
-    $exception->{line} = $params{line};
-    $exception->{package} = $params{pack};
-    $exception->{file} = $params{file};
-    
-    $exception->rethrow();
-}
+our $VERSION = $Business::UPS::Tracking::VERSION;
 
 use Exception::Class( 
     'Business::UPS::Tracking::X'    => {
@@ -52,7 +33,36 @@ use Exception::Class(
         isa           => 'Business::UPS::Tracking::X',    
         description   => 'Class error',
         fields        => [qw(method depth evaltext sub_name last_error sub is_require has_args)],
-    },    
+    },
 );
 
-1;
\ No newline at end of file
+sub new {
+    my ( $self, @args ) = @_;
+    
+    $self->create_error_exception(@args)->throw;
+}
+
+sub create_error_exception {
+    my ( $self, %params ) = @_;
+    
+    my $exception = Business::UPS::Tracking::X::CLASS->new( 
+        error       => $params{message},
+        method      => $params{method},
+        depth       => $params{depth},
+        evaltext    => $params{evaltext},
+        sub_name    => $params{sub_name},
+        last_error  => $params{last_error},
+        sub         => $params{sub},
+        is_require  => $params{is_require},
+        has_args    => $params{has_args},
+    );
+    $exception->{line} = $params{line};
+    $exception->{package} = $params{pack};
+    $exception->{file} = $params{file};
+    
+    return $exception;
+}
+
+
+
+1;
